use strict;
use warnings;

use Net::FTP;
use YAML qw/LoadFile/;

### check arguments

if (@ARGV == 0) {
	if ($INC{'PAR.pm'}) {
		print "usage: simple_upload.exe <target_file> [<target_file> ...]\n";
	}
	else {
		print "usage: simple_upload.pl <target_file> [<target_file> ...]\n";
	}
	system "pause";
	exit(1);
}

### print header
print <<HERE;
*** Simple Upload Script ***
HERE

### load YAML file
(my $conf_file = $0) =~ s/[^.]+$/yml/;;
my $setting = LoadFile($conf_file);


### decide host and path

foreach my $local (@ARGV) {
	my ($login, $remote);

	# find mapping for passed file
	foreach my $mapping (@{$setting->{Mappings}}) {
		if (($remote = $local) =~ s|^\Q$mapping->{LocalPath}\E|$mapping->{RemotePath}|) {
			$login = $mapping->{Login};
			$remote =~ s|\\|/|g;
			last;
		}
	}
	unless ($login) {
		print "Cannot map: $local\n";
		system "notepad.exe $conf_file";
		system "pause";
		exit(1);
	}

	# find login information
	my %inf = %{$setting->{Login}};
	unless (defined($inf{$login})) {
		print "login information isn't defined: $login\n";
		system "pause";
		exit(1);
	}
	my $host = $inf{$login}{Host};
	my $user = $inf{$login}{User};
	my $pass = $inf{$login}{Pass};

	### upload file

	print <<HERE;
-----------------------------
Host: $host
Local: $local
Remote: $remote
HERE

	my $ftp = Net::FTP->new(
		$host,
		%{$setting->{Options}}
	) or warn("Cannot connect to $host: $@"), system "pause", exit(1);

	$ftp->login($user, $pass)
	  or warn("Cannot login: ", $ftp->message), system "pause", exit(1);

	$ftp->binary()
	  or warn("binary failed: ", $ftp->message), system "pause", exit(1);

	$ftp->put($local, $remote)
	  or warn("put failed: ", $ftp->message), system "pause", exit(1);

	$ftp->quit;
}

system "pause";
